@@ -20,12 +20,13 @@ for (t in 1:T) {
 model <- online(
     y = matrix(y),
     experts = experts,
-    basis_knot_distance = 1,
+    tau = prob_grid,
+    b_smooth_pr = list(knots = 1, outer = FALSE),
     trace = FALSE
 )
 
-diff(model$weights[500, , 1])
+diff(model$weights[500, , , 1])
 
-diffs <- apply(model$weights[, , ], MARGIN = 1, FUN = diff)
+diffs <- apply(model$weights[, , , ], MARGIN = 1, FUN = diff)
 
-expect_true(sum(diffs) == 0)
+expect_true(sum(diffs) == 0)
\ No newline at end of file
