@@ -23,6 +23,7 @@ for (t in 1:T) {
 model <- online(
     y = matrix(y),
     experts = experts,
+    tau = prob_grid,
     trace = FALSE
 )
 
@@ -30,8 +31,8 @@ model <- online(
 expect_type(model, "list")
 
 # Dimensions
-expect_true(all(dim(model$weights) == c(length(y) + 1, P, N)))
-expect_true(all(dim(model$predictions) == c(length(y), P)))
+expect_true(all(dim(model$weights) == c(length(y) + 1, 1, P, N)))
+expect_true(all(dim(model$predictions) == c(length(y), 1, P)))
 
 # Missing values
 expect_true(all(!is.na(model$weights)))
